@@ -3,16 +3,13 @@ package manager
 import (
 	"context"
 
-	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
-
-	"github.com/weaveworks/eksctl/pkg/awsapi"
-
 	asgtypes "github.com/aws/aws-sdk-go-v2/service/autoscaling/types"
-
 	cfntypes "github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
 	cttypes "github.com/aws/aws-sdk-go-v2/service/cloudtrail/types"
+	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
 
 	"github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
+	"github.com/weaveworks/eksctl/pkg/awsapi"
 	"github.com/weaveworks/eksctl/pkg/cfn/builder"
 	iamoidc "github.com/weaveworks/eksctl/pkg/iam/oidc"
 	"github.com/weaveworks/eksctl/pkg/kubernetes"
@@ -42,12 +39,13 @@ var _ StackManager = &StackCollection{}
 //go:generate go run github.com/maxbrunsfeld/counterfeiter/v6 -generate
 //counterfeiter:generate -o fakes/fake_stack_manager.go . StackManager
 type StackManager interface {
-	AppendNewClusterStackResource(ctx context.Context, plan bool) (bool, error)
+	AppendNewClusterStackResource(ctx context.Context, extendForOutposts, plan bool) (bool, error)
 	CreateStack(ctx context.Context, name string, stack builder.ResourceSetReader, tags, parameters map[string]string, errs chan error) error
 	DeleteStackBySpec(ctx context.Context, s *Stack) (*Stack, error)
 	DeleteStackBySpecSync(ctx context.Context, s *Stack, errs chan error) error
 	DeleteStackSync(ctx context.Context, s *Stack) error
 	DeleteTasksForDeprecatedStacks(ctx context.Context) (*tasks.TaskTree, error)
+	DescribeClusterStackIfExists(ctx context.Context) (*Stack, error)
 	DescribeClusterStack(ctx context.Context) (*Stack, error)
 	DescribeIAMServiceAccountStacks(ctx context.Context) ([]*Stack, error)
 	DescribeNodeGroupStack(ctx context.Context, nodeGroupName string) (*Stack, error)
@@ -61,6 +59,7 @@ type StackManager interface {
 	DoWaitUntilStackIsCreated(ctx context.Context, i *Stack) error
 	EnsureMapPublicIPOnLaunchEnabled(ctx context.Context) error
 	FixClusterCompatibility(ctx context.Context) error
+	ClusterHasDedicatedVPC(ctx context.Context) (bool, error)
 	GetAutoScalingGroupDesiredCapacity(ctx context.Context, name string) (asgtypes.AutoScalingGroup, error)
 	GetAutoScalingGroupName(ctx context.Context, s *Stack) (string, error)
 	GetClusterStackIfExists(ctx context.Context) (*Stack, error)
@@ -83,7 +82,6 @@ type StackManager interface {
 	LookupCloudTrailEvents(ctx context.Context, i *Stack) ([]cttypes.Event, error)
 	MakeChangeSetName(action string) string
 	MakeClusterStackName() string
-	NewClusterCompatTask(ctx context.Context) tasks.Task
 	NewManagedNodeGroupTask(ctx context.Context, nodeGroups []*v1alpha5.ManagedNodeGroup, forceAddCNIPolicy bool, importer vpc.Importer) *tasks.TaskTree
 	NewTaskToDeleteAddonIAM(ctx context.Context, wait bool) (*tasks.TaskTree, error)
 	NewTaskToDeleteUnownedNodeGroup(ctx context.Context, clusterName, nodegroup string, eksAPI awsapi.EKS, waitCondition *DeleteWaitCondition) tasks.Task
