@@ -51,7 +51,7 @@ func doGetIdentityProvider(cmd *cmdutils.Cmd, params getCmdParams, name string)
 		logger.Writer = os.Stderr
 	}
 
-	ctx := context.TODO()
+	ctx := context.Background()
 	ctl, err := cmd.NewProviderForExistingCluster(ctx)
 	if err != nil {
 		return err
@@ -64,7 +64,7 @@ func doGetIdentityProvider(cmd *cmdutils.Cmd, params getCmdParams, name string)
 
 	manager := identityproviders.NewManager(
 		*cfg.Metadata,
-		ctl.Provider.EKS(),
+		ctl.AWSProvider.EKS(),
 	)
 
 	summaries, err := manager.Get(ctx, identityproviders.GetIdentityProvidersOptions{Name: name})
