@@ -70,9 +70,11 @@ type endpointAccessCase struct {
 }
 
 type importAllSubnetsCase struct {
-	cfg      api.ClusterConfig
-	expected api.ClusterSubnets
-	error    error
+	cfg                     api.ClusterConfig
+	privateSubnetOutpostARN *string
+
+	expectedSubnets api.ClusterSubnets
+	expectedErr     string
 }
 
 type cleanupSubnetsCase struct {
@@ -125,7 +127,7 @@ var _ = Describe("VPC", func() {
 				Mask: []byte{255, 255, 0, 0},
 			}
 
-			subnets, err := SplitInto16(&input)
+			subnets, err := SplitInto(&input, 16, 20)
 			Expect(err).NotTo(HaveOccurred())
 			Expect(subnets).To(HaveLen(16))
 			for i, subnet := range subnets {
@@ -154,7 +156,7 @@ var _ = Describe("VPC", func() {
 				Mask: []byte{255, 255, 0, 0},
 			}
 
-			subnets, err := SplitInto8(&input)
+			subnets, err := SplitInto(&input, 8, 19)
 			Expect(err).NotTo(HaveOccurred())
 			Expect(subnets).To(HaveLen(8))
 			for i, subnet := range subnets {
@@ -164,6 +166,20 @@ var _ = Describe("VPC", func() {
 		})
 	})
 
+	Describe("SplitInto with an invalid CIDR block size", func() {
+		It("should return an error if the block size is invalid", func() {
+			blockSizes := []int{29, 15}
+			for _, s := range blockSizes {
+				_, err := SplitInto(&net.IPNet{
+					IP:   []byte{192, 168, 0, 0},
+					Mask: []byte{255, 255, 0, 0},
+				}, 8, s)
+				Expect(err).To(MatchError(ContainSubstring("CIDR block size must be between a /16 netmask and /28 netmask")))
+			}
+
+		})
+	})
+
 	DescribeTable("Set subnets",
 		func(subnetsCase setSubnetsCase) {
 			err := SetSubnets(subnetsCase.vpc, subnetsCase.availabilityZones, subnetsCase.localZones)
@@ -227,6 +243,10 @@ var _ = Describe("VPC", func() {
 			availabilityZones: []string{"us-west-2a", "us-west-2b"},
 			localZones:        []string{"us-west-2-lax-1a", "us-west-lax-1b"},
 		}),
+		Entry("VPC with a single AZ (Outposts)", setSubnetsCase{
+			vpc:               api.NewClusterVPC(false),
+			availabilityZones: []string{"us-west-2a"},
+		}),
 	)
 
 	type setSubnetsEntry struct {
@@ -359,6 +379,32 @@ var _ = Describe("VPC", func() {
 				Private: api.NewAZSubnetMapping(),
 			},
 		}),
+
+		Entry("control plane on Outposts", setSubnetsEntry{
+			availabilityZones: []string{"us-west-2a"},
+
+			expectedSubnets: &api.ClusterSubnets{
+				Public: api.AZSubnetMapping{
+					"us-west-2a": api.AZSubnetSpec{
+						AZ:        "us-west-2a",
+						CIDR:      ipnet.MustParseCIDR("192.168.0.0/19"),
+						CIDRIndex: 0,
+					},
+				},
+				Private: api.AZSubnetMapping{
+					"us-west-2a": api.AZSubnetSpec{
+						AZ:        "us-west-2a",
+						CIDR:      ipnet.MustParseCIDR("192.168.32.0/19"),
+						CIDRIndex: 1,
+					},
+				},
+			},
+
+			expectedLocalZoneSubnets: &api.ClusterSubnets{
+				Public:  api.NewAZSubnetMapping(),
+				Private: api.NewAZSubnetMapping(),
+			},
+		}),
 	)
 
 	DescribeTable("Use from Cluster",
@@ -510,7 +556,7 @@ var _ = Describe("VPC", func() {
 				ManageSharedNodeSecurityGroupRules: aws.Bool(true),
 				AutoAllocateIPv6:                   aws.Bool(false),
 				NAT: &api.ClusterNAT{
-					Gateway: aws.String("Disable"),
+					Gateway: aws.String("Single"),
 				},
 				ClusterEndpoints: &api.ClusterEndpoints{
 					PublicAccess:  aws.Bool(true),
@@ -980,6 +1026,7 @@ var _ = Describe("VPC", func() {
 						CidrBlock:        strings.Pointer("192.168.0.0/20"),
 						SubnetId:         strings.Pointer("private1"),
 						VpcId:            strings.Pointer("vpc1"),
+						OutpostArn:       e.privateSubnetOutpostARN,
 					},
 				},
 			}, nil)
@@ -1011,11 +1058,11 @@ var _ = Describe("VPC", func() {
 			}, nil)
 
 			err := ImportSubnetsFromSpec(context.Background(), p, &e.cfg)
-			if e.error != nil {
-				Expect(err).To(MatchError(e.error.Error()))
+			if e.expectedErr != "" {
+				Expect(err).To(MatchError(e.expectedErr))
 			} else {
 				Expect(err).NotTo(HaveOccurred())
-				Expect(*e.cfg.VPC.Subnets).To(Equal(e.expected))
+				Expect(*e.cfg.VPC.Subnets).To(Equal(e.expectedSubnets))
 			}
 		},
 
@@ -1039,7 +1086,7 @@ var _ = Describe("VPC", func() {
 					},
 				},
 			},
-			expected: api.ClusterSubnets{
+			expectedSubnets: api.ClusterSubnets{
 				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
 					"az1": {
 						ID:   "private1",
@@ -1055,7 +1102,6 @@ var _ = Describe("VPC", func() {
 					},
 				}),
 			},
-			error: nil,
 		}),
 
 		Entry("Private subnet is not matching with AZ", importAllSubnetsCase{
@@ -1078,7 +1124,7 @@ var _ = Describe("VPC", func() {
 					},
 				},
 			},
-			expected: api.ClusterSubnets{
+			expectedSubnets: api.ClusterSubnets{
 				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
 					"invalidAZ": {
 						ID:   "private1",
@@ -1094,7 +1140,6 @@ var _ = Describe("VPC", func() {
 					},
 				}),
 			},
-			error: nil,
 		}),
 		Entry("Public subnet is not matching with AZ", importAllSubnetsCase{
 			cfg: api.ClusterConfig{
@@ -1116,7 +1161,7 @@ var _ = Describe("VPC", func() {
 					},
 				},
 			},
-			expected: api.ClusterSubnets{
+			expectedSubnets: api.ClusterSubnets{
 				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
 					"az1": {
 						ID:   "private1",
@@ -1132,7 +1177,6 @@ var _ = Describe("VPC", func() {
 					},
 				}),
 			},
-			error: nil,
 		}),
 		Entry("Subnets given names and identified by various params", importAllSubnetsCase{
 			cfg: api.ClusterConfig{
@@ -1156,7 +1200,7 @@ var _ = Describe("VPC", func() {
 					},
 				},
 			},
-			expected: api.ClusterSubnets{
+			expectedSubnets: api.ClusterSubnets{
 				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
 					"subone": {
 						ID:   "private1",
@@ -1175,7 +1219,6 @@ var _ = Describe("VPC", func() {
 					},
 				}),
 			},
-			error: nil,
 		}),
 		Entry("Subnets identified by CIDR", importAllSubnetsCase{
 			cfg: api.ClusterConfig{
@@ -1200,7 +1243,7 @@ var _ = Describe("VPC", func() {
 					},
 				},
 			},
-			expected: api.ClusterSubnets{
+			expectedSubnets: api.ClusterSubnets{
 				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
 					"az1": {
 						ID:   "private1",
@@ -1221,7 +1264,83 @@ var _ = Describe("VPC", func() {
 					},
 				}),
 			},
-			error: nil,
+		}),
+
+		Entry("[Outposts] Subnets not on Outposts", importAllSubnetsCase{
+			cfg: api.ClusterConfig{
+				VPC: &api.ClusterVPC{
+					Network: api.Network{
+						ID: "vpc1",
+					},
+					Subnets: &api.ClusterSubnets{
+						Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
+							"az1": {
+								ID: "private1",
+							},
+						}),
+					},
+				},
+				Outpost: &api.Outpost{
+					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+				},
+			},
+
+			expectedErr: "all subnets must be on the control plane Outpost when specifying pre-existing subnets for a cluster on Outposts; found invalid private subnet(s): private1",
+		}),
+
+		Entry("[Outposts] Subnets not on the same Outpost as the control plane", importAllSubnetsCase{
+			cfg: api.ClusterConfig{
+				VPC: &api.ClusterVPC{
+					Network: api.Network{
+						ID: "vpc1",
+					},
+					Subnets: &api.ClusterSubnets{
+						Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
+							"az1": {
+								ID: "private1",
+							},
+						}),
+					},
+				},
+				Outpost: &api.Outpost{
+					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+				},
+			},
+			privateSubnetOutpostARN: aws.String("arn:aws:outposts:us-west-2:1234:outpost/op-5678"),
+
+			expectedErr: "all subnets must be on the control plane Outpost when specifying pre-existing subnets for a cluster on Outposts; found invalid private subnet(s): private1",
+		}),
+
+		Entry("[Outposts] Subnets on the same Outpost as the control plane", importAllSubnetsCase{
+			cfg: api.ClusterConfig{
+				VPC: &api.ClusterVPC{
+					Network: api.Network{
+						ID: "vpc1",
+					},
+					Subnets: &api.ClusterSubnets{
+						Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
+							"az1": {
+								ID: "private1",
+							},
+						}),
+					},
+				},
+				Outpost: &api.Outpost{
+					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+				},
+			},
+			privateSubnetOutpostARN: aws.String("arn:aws:outposts:us-west-2:1234:outpost/op-1234"),
+
+			expectedSubnets: api.ClusterSubnets{
+				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
+					"az1": {
+						ID:         "private1",
+						AZ:         "az1",
+						CIDR:       ipnet.MustParseCIDR("192.168.0.0/20"),
+						OutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					},
+				}),
+			},
 		}),
 	)
 
